@@ -5,13 +5,13 @@ use std::collections::HashMap;
 
 pub struct FuncMapper {
     func_map: Vec<Option<HashMap<String, usize>>>,
-    func_list: Vec<Func>,
+    func_list: Vec<Box<Func>>,
 }
 
 impl FuncMapper {
     pub fn new(
         func_map: Vec<Option<HashMap<String, usize>>>,
-        func_list: Vec<Func>
+        func_list: Vec<Box<Func>>
     ) -> Self {
         FuncMapper {
             func_map: func_map,
@@ -21,7 +21,7 @@ impl FuncMapper {
 
     pub fn get(&self, func_id: usize) -> Result<&Func> {
         match self.func_list.get(func_id) {
-            Some(some) => Ok(some),
+            Some(some) => Ok(some.as_ref()),
             None => Err(ErrorKind::EventNotFoundInEventList(func_id, self.func_list.len()).into())
         }
     }
@@ -40,7 +40,7 @@ impl FuncMapper {
         }
     }
 
-    pub fn get_raw_list(&self) -> &Vec<Func> {
+    pub fn get_raw_list(&self) -> &Vec<Box<Func>> {
         &self.func_list
     }
 
