@@ -1,8 +1,8 @@
 use { file_funcs, FuncMapper, Payload, string };
 use error::*;
-use func::Func;
+use func::{ Func, new_func };
 use libflo_module::{ ModuleMapper, PathResolver, self_module_name };
-use serialization::{ Dll, Func as SerialFunc };
+use serialization::{ DllSerde, FuncSerde, ParameterSerde };
 use sharedlib::LibArc;
 use std::collections::HashMap;
 
@@ -33,12 +33,12 @@ pub unsafe fn load(
 }
 
 unsafe fn create_funcs(
-    dll: Dll,
+    dll: DllSerde,
     module_name: &String,
     module_id: usize,
     self_module_id: usize,
     path_resolver: &PathResolver,
-    pre_func_list: &mut Vec<Func>,
+    pre_func_list: &mut Vec<Box<Func>>,
     pre_func_map: &mut Vec<Option<HashMap<String, usize>>>,
 ) -> Result<()> {
     let (path, funcs) = dll.destructure();
@@ -53,16 +53,18 @@ unsafe fn create_funcs(
 }
 
 unsafe fn create_func(
-    func: SerialFunc,
+    func: FuncSerde,
     library: &LibArc,
     module_name: &String,
     module_id: usize,
-    pre_func_list: &mut Vec<Func>,
+    pre_func_list: &mut Vec<Box<Func>>,
     pre_func_map: &mut Vec<Option<HashMap<String, usize>>>,
 ) -> Result<()> {
-    let (func_type, has_input, has_output, symbol, use_as) = func.destructure();
+    let (input, output, symbol, name) = func.destructure();
 
-    let name = use_as.unwrap_or(symbol.clone());
+    let input = input.unwrap_or(ParameterSerde::none);
+    let output = output.unwrap_or(ParameterSerde::none);
+    let name = name.unwrap_or(symbol.clone());
     let func_id = pre_func_list.len();
 
     if let Some(&None) = pre_func_map.get(module_id) {
@@ -75,9 +77,7 @@ unsafe fn create_func(
         }
     }
 
-    let has_input = has_input.unwrap_or(false);
-    let has_output = has_output.unwrap_or(false);
-    let func = Func::new(library, &symbol, func_type, has_input, has_output)?;
+    let func = new_func(library, symbol, input, output)?;
     pre_func_list.push(func);
 
     Ok(())
