@@ -1,4 +1,4 @@
-use func::Func;
+use func::Input;
 use test::res::dll;
 
 #[test]
@@ -12,13 +12,10 @@ fn hello_world() {
     let func_mapper = dll.destructure();
     let (module_mapper, _) = module.destructure();
 
-    let libflo_func_test_0_id = module_mapper.get_id("libflo_func_test_0").unwrap();
+    let libflo_func_test_0_id = module_mapper.get("libflo_func_test_0").unwrap();
     let hello_world_id = func_mapper.get_id(libflo_func_test_0_id, "hello_world".to_string()).unwrap();
 
-    let hello_world_func = func_mapper.get_func(hello_world_id).unwrap();
+    let hello_world_func = func_mapper.get(hello_world_id).unwrap();
 
-    match hello_world_func {
-        &Func::NativeFuncNone(ref func) => unsafe { func.clone().call().unwrap() },
-        _ => panic!(),
-    }
+    unsafe { hello_world_func.call(Input::None).unwrap() };
 }
